'''
Created on Jul 22, 2014

@author: scrosby
'''
import requests

class Releases:
    def __init__(self, start, end=None):
        self.start = start
        if end is None:
            self.end = start
        else:
            self.end = end
        r = requests.get('https://mc-release-calendar.herokuapp.com/releases?starts_after={}&ends_before={}'.format(self.start, self.end), headers={'content-type':'application/json'})
        releases = r.json()
        self.maint='Not Open'
        self.master='Not Open'
        for release in releases:
            if release['maint'] == True:
                self.maint = release['name']
            else:
                self.master = release['name']
        